# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/staking/v1beta1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/staking/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/staking/v1beta1/query.proto\x12\x16\x63osmos.staking.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/staking/v1beta1/staking.proto\"d\n\x16QueryValidatorsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n\x17QueryValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"/\n\x15QueryValidatorRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\"T\n\x16QueryValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\"v\n QueryValidatorDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xc7\x01\n!QueryValidatorDelegationsResponse\x12\x65\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\x1b\xc8\xde\x1f\x00\xaa\xdf\x1f\x13\x44\x65legationResponses\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x7f\n)QueryValidatorUnbondingDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb9\x01\n*QueryValidatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"R\n\x16QueryDelegationRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"b\n\x17QueryDelegationResponse\x12G\n\x13\x64\x65legation_response\x18\x01 \x01(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponse\"[\n\x1fQueryUnbondingDelegationRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"e\n QueryUnbondingDelegationResponse\x12\x41\n\x06unbond\x18\x01 \x01(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\"\x80\x01\n QueryDelegatorDelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb0\x01\n!QueryDelegatorDelegationsResponse\x12N\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x89\x01\n)QueryDelegatorUnbondingDelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb9\x01\n*QueryDelegatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xb1\x01\n\x19QueryRedelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x1a\n\x12src_validator_addr\x18\x02 \x01(\t\x12\x1a\n\x12\x64st_validator_addr\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xad\x01\n\x1aQueryRedelegationsResponse\x12R\n\x16redelegation_responses\x18\x01 \x03(\x0b\x32,.cosmos.staking.v1beta1.RedelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x7f\n\x1fQueryDelegatorValidatorsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x9c\x01\n QueryDelegatorValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Z\n\x1eQueryDelegatorValidatorRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"]\n\x1fQueryDelegatorValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\",\n\x1aQueryHistoricalInfoRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"S\n\x1bQueryHistoricalInfoResponse\x12\x34\n\x04hist\x18\x01 \x01(\x0b\x32&.cosmos.staking.v1beta1.HistoricalInfo\"\x12\n\x10QueryPoolRequest\"E\n\x11QueryPoolResponse\x12\x30\n\x04pool\x18\x01 \x01(\x0b\x32\x1c.cosmos.staking.v1beta1.PoolB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"K\n\x13QueryParamsResponse\x12\x34\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x32\xea\x15\n\x05Query\x12\x99\x01\n\nValidators\x12..cosmos.staking.v1beta1.QueryValidatorsRequest\x1a/.cosmos.staking.v1beta1.QueryValidatorsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/cosmos/staking/v1beta1/validators\x12\xa7\x01\n\tValidator\x12-.cosmos.staking.v1beta1.QueryValidatorRequest\x1a..cosmos.staking.v1beta1.QueryValidatorResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/staking/v1beta1/validators/{validator_addr}\x12\xd4\x01\n\x14ValidatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryValidatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryValidatorDelegationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations\x12\xf9\x01\n\x1dValidatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations\x12\xc7\x01\n\nDelegation\x12..cosmos.staking.v1beta1.QueryDelegationRequest\x1a/.cosmos.staking.v1beta1.QueryDelegationResponse\"X\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}\x12\xf7\x01\n\x13UnbondingDelegation\x12\x37.cosmos.staking.v1beta1.QueryUnbondingDelegationRequest\x1a\x38.cosmos.staking.v1beta1.QueryUnbondingDelegationResponse\"m\x82\xd3\xe4\x93\x02g\x12\x65/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation\x12\xc9\x01\n\x14\x44\x65legatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/staking/v1beta1/delegations/{delegator_addr}\x12\xf9\x01\n\x1d\x44\x65legatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations\x12\xc1\x01\n\rRedelegations\x12\x31.cosmos.staking.v1beta1.QueryRedelegationsRequest\x1a\x32.cosmos.staking.v1beta1.QueryRedelegationsResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations\x12\xd0\x01\n\x13\x44\x65legatorValidators\x12\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest\x1a\x38.cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators\x12\xde\x01\n\x12\x44\x65legatorValidator\x12\x36.cosmos.staking.v1beta1.QueryDelegatorValidatorRequest\x1a\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}\x12\xb3\x01\n\x0eHistoricalInfo\x12\x32.cosmos.staking.v1beta1.QueryHistoricalInfoRequest\x1a\x33.cosmos.staking.v1beta1.QueryHistoricalInfoResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/staking/v1beta1/historical_info/{height}\x12\x81\x01\n\x04Pool\x12(.cosmos.staking.v1beta1.QueryPoolRequest\x1a).cosmos.staking.v1beta1.QueryPoolResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool\x12\x89\x01\n\x06Params\x12*.cosmos.staking.v1beta1.QueryParamsRequest\x1a+.cosmos.staking.v1beta1.QueryParamsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/paramsB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _globals['_QUERYVALIDATORSRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_QUERYVALIDATORSRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVALIDATORRESPONSE'].fields_by_name['validator']._loaded_options = None
  _globals['_QUERYVALIDATORRESPONSE'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._loaded_options = None
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\252\337\037\023DelegationResponses'
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._loaded_options = None
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELEGATIONREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATIONREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE'].fields_by_name['unbond']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE'].fields_by_name['unbond']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYREDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYREDELEGATIONSRESPONSE'].fields_by_name['redelegation_responses']._loaded_options = None
  _globals['_QUERYREDELEGATIONSRESPONSE'].fields_by_name['redelegation_responses']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORVALIDATORRESPONSE'].fields_by_name['validator']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORRESPONSE'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPOOLRESPONSE'].fields_by_name['pool']._loaded_options = None
  _globals['_QUERYPOOLRESPONSE'].fields_by_name['pool']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Validators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Validators']._serialized_options = b'\202\323\344\223\002$\022\"/cosmos/staking/v1beta1/validators'
  _globals['_QUERY'].methods_by_name['Validator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Validator']._serialized_options = b'\202\323\344\223\0025\0223/cosmos/staking/v1beta1/validators/{validator_addr}'
  _globals['_QUERY'].methods_by_name['ValidatorDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorDelegations']._serialized_options = b'\202\323\344\223\002A\022?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations'
  _globals['_QUERY'].methods_by_name['ValidatorUnbondingDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorUnbondingDelegations']._serialized_options = b'\202\323\344\223\002K\022I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations'
  _globals['_QUERY'].methods_by_name['Delegation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Delegation']._serialized_options = b'\202\323\344\223\002R\022P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}'
  _globals['_QUERY'].methods_by_name['UnbondingDelegation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UnbondingDelegation']._serialized_options = b'\202\323\344\223\002g\022e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation'
  _globals['_QUERY'].methods_by_name['DelegatorDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorDelegations']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/staking/v1beta1/delegations/{delegator_addr}'
  _globals['_QUERY'].methods_by_name['DelegatorUnbondingDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorUnbondingDelegations']._serialized_options = b'\202\323\344\223\002K\022I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations'
  _globals['_QUERY'].methods_by_name['Redelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Redelegations']._serialized_options = b'\202\323\344\223\002C\022A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations'
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._serialized_options = b'\202\323\344\223\002@\022>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators'
  _globals['_QUERY'].methods_by_name['DelegatorValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorValidator']._serialized_options = b'\202\323\344\223\002Q\022O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}'
  _globals['_QUERY'].methods_by_name['HistoricalInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['HistoricalInfo']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/staking/v1beta1/historical_info/{height}'
  _globals['_QUERY'].methods_by_name['Pool']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Pool']._serialized_options = b'\202\323\344\223\002\036\022\034/cosmos/staking/v1beta1/pool'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002 \022\036/cosmos/staking/v1beta1/params'
  _globals['_QUERYVALIDATORSREQUEST']._serialized_start=196
  _globals['_QUERYVALIDATORSREQUEST']._serialized_end=296
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_start=299
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_end=446
  _globals['_QUERYVALIDATORREQUEST']._serialized_start=448
  _globals['_QUERYVALIDATORREQUEST']._serialized_end=495
  _globals['_QUERYVALIDATORRESPONSE']._serialized_start=497
  _globals['_QUERYVALIDATORRESPONSE']._serialized_end=581
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_start=583
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_end=701
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_start=704
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_end=903
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=905
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=1032
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=1035
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=1220
  _globals['_QUERYDELEGATIONREQUEST']._serialized_start=1222
  _globals['_QUERYDELEGATIONREQUEST']._serialized_end=1304
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_start=1306
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_end=1404
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_start=1406
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_end=1497
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_start=1499
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_end=1600
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_start=1603
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_end=1731
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_start=1734
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_end=1910
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=1913
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=2050
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=2053
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=2238
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_start=2241
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_end=2418
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_start=2421
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_end=2594
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_start=2596
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_end=2723
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_start=2726
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_end=2882
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_start=2884
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_end=2974
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_start=2976
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_end=3069
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_start=3071
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_end=3115
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_start=3117
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_end=3200
  _globals['_QUERYPOOLREQUEST']._serialized_start=3202
  _globals['_QUERYPOOLREQUEST']._serialized_end=3220
  _globals['_QUERYPOOLRESPONSE']._serialized_start=3222
  _globals['_QUERYPOOLRESPONSE']._serialized_end=3291
  _globals['_QUERYPARAMSREQUEST']._serialized_start=3293
  _globals['_QUERYPARAMSREQUEST']._serialized_end=3313
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=3315
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=3390
  _globals['_QUERY']._serialized_start=3393
  _globals['_QUERY']._serialized_end=6187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/sanctum/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/sanctum/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cneurion/sanctum/params.proto\x12\x0fneurion.sanctum\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"\xe8\x01\n\x06Params\x12\x19\n\x11min_dataset_stake\x18\x01 \x01(\x04\x12\x17\n\x0fmin_dataset_fee\x18\x02 \x01(\x04\x12\x15\n\radmin_address\x18\x03 \x01(\t\x12\x14\n\x0cprotocol_fee\x18\x04 \x01(\x04\x12\x18\n\x10protocol_deposit\x18\x05 \x01(\x04\x12\x1e\n\x16request_processing_fee\x18\x06 \x01(\x04\x12 \n\x18staker_reward_percentage\x18\x07 \x01(\x04:!\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x18neurion/x/sanctum/ParamsB\x19Z\x17neurion/x/sanctum/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.sanctum.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/sanctum/types'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\030neurion/x/sanctum/Params'
  _globals['_PARAMS']._serialized_start=91
  _globals['_PARAMS']._serialized_end=323
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Minter(_message.Message):
    __slots__ = ("inflation", "annual_provisions")
    INFLATION_FIELD_NUMBER: _ClassVar[int]
    ANNUAL_PROVISIONS_FIELD_NUMBER: _ClassVar[int]
    inflation: str
    annual_provisions: str
    def __init__(self, inflation: _Optional[str] = ..., annual_provisions: _Optional[str] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("mint_denom", "inflation_rate", "blocks_per_year")
    MINT_DENOM_FIELD_NUMBER: _ClassVar[int]
    INFLATION_RATE_FIELD_NUMBER: _ClassVar[int]
    BLOCKS_PER_YEAR_FIELD_NUMBER: _ClassVar[int]
    mint_denom: str
    inflation_rate: str
    blocks_per_year: int
    def __init__(self, mint_denom: _Optional[str] = ..., inflation_rate: _Optional[str] = ..., blocks_per_year: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/consensus/v1beta1/wal.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/consensus/v1beta1/wal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cometbft.consensus.v1beta1 import types_pb2 as cometbft_dot_consensus_dot_v1beta1_dot_types__pb2
from cometbft.types.v1beta1 import events_pb2 as cometbft_dot_types_dot_v1beta1_dot_events__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cometbft/consensus/v1beta1/wal.proto\x12\x1a\x63ometbft.consensus.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cometbft/consensus/v1beta1/types.proto\x1a#cometbft/types/v1beta1/events.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"^\n\x07MsgInfo\x12\x36\n\x03msg\x18\x01 \x01(\x0b\x32#.cometbft.consensus.v1beta1.MessageB\x04\xc8\xde\x1f\x00\x12\x1b\n\x07peer_id\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06PeerID\"q\n\x0bTimeoutInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x0c\n\x04step\x18\x04 \x01(\r\"\x1b\n\tEndHeight\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x99\x02\n\nWALMessage\x12M\n\x16\x65vent_data_round_state\x18\x01 \x01(\x0b\x32+.cometbft.types.v1beta1.EventDataRoundStateH\x00\x12\x37\n\x08msg_info\x18\x02 \x01(\x0b\x32#.cometbft.consensus.v1beta1.MsgInfoH\x00\x12?\n\x0ctimeout_info\x18\x03 \x01(\x0b\x32\'.cometbft.consensus.v1beta1.TimeoutInfoH\x00\x12;\n\nend_height\x18\x04 \x01(\x0b\x32%.cometbft.consensus.v1beta1.EndHeightH\x00\x42\x05\n\x03sum\"z\n\x0fTimedWALMessage\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x33\n\x03msg\x18\x02 \x01(\x0b\x32&.cometbft.consensus.v1beta1.WALMessageB=Z;github.com/cometbft/cometbft/api/cometbft/consensus/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.consensus.v1beta1.wal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/cometbft/cometbft/api/cometbft/consensus/v1beta1'
  _globals['_MSGINFO'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['msg']._serialized_options = b'\310\336\037\000'
  _globals['_MSGINFO'].fields_by_name['peer_id']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['peer_id']._serialized_options = b'\342\336\037\006PeerID'
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._loaded_options = None
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._loaded_options = None
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MSGINFO']._serialized_start=232
  _globals['_MSGINFO']._serialized_end=326
  _globals['_TIMEOUTINFO']._serialized_start=328
  _globals['_TIMEOUTINFO']._serialized_end=441
  _globals['_ENDHEIGHT']._serialized_start=443
  _globals['_ENDHEIGHT']._serialized_end=470
  _globals['_WALMESSAGE']._serialized_start=473
  _globals['_WALMESSAGE']._serialized_end=754
  _globals['_TIMEDWALMESSAGE']._serialized_start=756
  _globals['_TIMEDWALMESSAGE']._serialized_end=878
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/neurion/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/neurion/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.neurion import params_pb2 as neurion_dot_neurion_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bneurion/neurion/query.proto\x12\x0fneurion.neurion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cneurion/neurion/params.proto\"\x14\n\x12QueryParamsRequest\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x17.neurion.neurion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32}\n\x05Query\x12t\n\x06Params\x12#.neurion.neurion.QueryParamsRequest\x1a$.neurion.neurion.QueryParamsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/neurion/neurion/paramsB\x19Z\x17neurion/x/neurion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.neurion.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/neurion/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\031\022\027/neurion/neurion/params'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=193
  _globals['_QUERYPARAMSREQUEST']._serialized_end=213
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=215
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=288
  _globals['_QUERY']._serialized_start=290
  _globals['_QUERY']._serialized_end=415
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v2/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v2/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.crypto.v1 import proof_pb2 as cometbft_dot_crypto_dot_v1_dot_proof__pb2
from cometbft.types.v2 import validator_pb2 as cometbft_dot_types_dot_v2_dot_validator__pb2
from cometbft.version.v1 import types_pb2 as cometbft_dot_version_dot_v1_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/types/v2/types.proto\x12\x11\x63ometbft.types.v2\x1a\x1e\x63ometbft/crypto/v1/proof.proto\x1a!cometbft/types/v2/validator.proto\x1a\x1f\x63ometbft/version/v1/types.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\",\n\rPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"T\n\x04Part\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x62ytes\x18\x02 \x01(\x0c\x12.\n\x05proof\x18\x03 \x01(\x0b\x32\x19.cometbft.crypto.v1.ProofB\x04\xc8\xde\x1f\x00\"X\n\x07\x42lockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12?\n\x0fpart_set_header\x18\x02 \x01(\x0b\x32 .cometbft.types.v2.PartSetHeaderB\x04\xc8\xde\x1f\x00\"\xb5\x03\n\x06Header\x12\x35\n\x07version\x18\x01 \x01(\x0b\x32\x1e.cometbft.version.v1.ConsensusB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x37\n\rlast_block_id\x18\x05 \x01(\x0b\x32\x1a.cometbft.types.v2.BlockIDB\x04\xc8\xde\x1f\x00\x12\x18\n\x10last_commit_hash\x18\x06 \x01(\x0c\x12\x11\n\tdata_hash\x18\x07 \x01(\x0c\x12\x17\n\x0fvalidators_hash\x18\x08 \x01(\x0c\x12\x1c\n\x14next_validators_hash\x18\t \x01(\x0c\x12\x16\n\x0e\x63onsensus_hash\x18\n \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\x0b \x01(\x0c\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x15\n\revidence_hash\x18\r \x01(\x0c\x12\x18\n\x10proposer_address\x18\x0e \x01(\x0c\"\x13\n\x04\x44\x61ta\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"\x82\x03\n\x04Vote\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .cometbft.types.v2.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12=\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x1a.cometbft.types.v2.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x19\n\x11validator_address\x18\x06 \x01(\x0c\x12\x17\n\x0fvalidator_index\x18\x07 \x01(\x05\x12\x11\n\tsignature\x18\x08 \x01(\x0c\x12\x11\n\textension\x18\t \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\n \x01(\x0c\x12\x18\n\x10non_rp_extension\x18\x0b \x01(\x0c\x12\"\n\x1anon_rp_extension_signature\x18\x0c \x01(\x0c\"\x9e\x01\n\x06\x43ommit\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12=\n\x08\x62lock_id\x18\x03 \x01(\x0b\x32\x1a.cometbft.types.v2.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x36\n\nsignatures\x18\x04 \x03(\x0b\x32\x1c.cometbft.types.v2.CommitSigB\x04\xc8\xde\x1f\x00\"\xa9\x01\n\tCommitSig\x12\x35\n\rblock_id_flag\x18\x01 \x01(\x0e\x32\x1e.cometbft.types.v2.BlockIDFlag\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x37\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x04 \x01(\x0c\"\xb7\x01\n\x0e\x45xtendedCommit\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12=\n\x08\x62lock_id\x18\x03 \x01(\x0b\x32\x1a.cometbft.types.v2.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12G\n\x13\x65xtended_signatures\x18\x04 \x03(\x0b\x32$.cometbft.types.v2.ExtendedCommitSigB\x04\xc8\xde\x1f\x00\"\x9f\x02\n\x11\x45xtendedCommitSig\x12\x35\n\rblock_id_flag\x18\x01 \x01(\x0e\x32\x1e.cometbft.types.v2.BlockIDFlag\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x37\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x11\n\textension\x18\x05 \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\x06 \x01(\x0c\x12\x18\n\x10non_rp_extension\x18\x07 \x01(\x0c\x12\"\n\x1anon_rp_extension_signature\x18\x08 \x01(\x0c\"\xf7\x01\n\x08Proposal\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .cometbft.types.v2.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x11\n\tpol_round\x18\x04 \x01(\x05\x12=\n\x08\x62lock_id\x18\x05 \x01(\x0b\x32\x1a.cometbft.types.v2.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x07 \x01(\x0c\"d\n\x0cSignedHeader\x12)\n\x06header\x18\x01 \x01(\x0b\x32\x19.cometbft.types.v2.Header\x12)\n\x06\x63ommit\x18\x02 \x01(\x0b\x32\x19.cometbft.types.v2.Commit\"|\n\nLightBlock\x12\x36\n\rsigned_header\x18\x01 \x01(\x0b\x32\x1f.cometbft.types.v2.SignedHeader\x12\x36\n\rvalidator_set\x18\x02 \x01(\x0b\x32\x1f.cometbft.types.v2.ValidatorSet\"\xa0\x01\n\tBlockMeta\x12=\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x1a.cometbft.types.v2.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x12\n\nblock_size\x18\x02 \x01(\x03\x12/\n\x06header\x18\x03 \x01(\x0b\x32\x19.cometbft.types.v2.HeaderB\x04\xc8\xde\x1f\x00\x12\x0f\n\x07num_txs\x18\x04 \x01(\x03\"T\n\x07TxProof\x12\x11\n\troot_hash\x18\x01 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12(\n\x05proof\x18\x03 \x01(\x0b\x32\x19.cometbft.crypto.v1.Proof*\xd7\x01\n\rSignedMsgType\x12,\n\x17SIGNED_MSG_TYPE_UNKNOWN\x10\x00\x1a\x0f\x8a\x9d \x0bUnknownType\x12,\n\x17SIGNED_MSG_TYPE_PREVOTE\x10\x01\x1a\x0f\x8a\x9d \x0bPrevoteType\x12\x30\n\x19SIGNED_MSG_TYPE_PRECOMMIT\x10\x02\x1a\x11\x8a\x9d \rPrecommitType\x12.\n\x18SIGNED_MSG_TYPE_PROPOSAL\x10 \x1a\x10\x8a\x9d \x0cProposalType\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42\x34Z2github.com/cometbft/cometbft/api/cometbft/types/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/types/v2'
  _globals['_SIGNEDMSGTYPE']._loaded_options = None
  _globals['_SIGNEDMSGTYPE']._serialized_options = b'\210\243\036\000\250\244\036\001'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_UNKNOWN"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_UNKNOWN"]._serialized_options = b'\212\235 \013UnknownType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PREVOTE"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PREVOTE"]._serialized_options = b'\212\235 \013PrevoteType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PRECOMMIT"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PRECOMMIT"]._serialized_options = b'\212\235 \rPrecommitType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PROPOSAL"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PROPOSAL"]._serialized_options = b'\212\235 \014ProposalType'
  _globals['_PART'].fields_by_name['proof']._loaded_options = None
  _globals['_PART'].fields_by_name['proof']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKID'].fields_by_name['part_set_header']._loaded_options = None
  _globals['_BLOCKID'].fields_by_name['part_set_header']._serialized_options = b'\310\336\037\000'
  _globals['_HEADER'].fields_by_name['version']._loaded_options = None
  _globals['_HEADER'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_HEADER'].fields_by_name['chain_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_HEADER'].fields_by_name['time']._loaded_options = None
  _globals['_HEADER'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_HEADER'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000'
  _globals['_VOTE'].fields_by_name['block_id']._loaded_options = None
  _globals['_VOTE'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_VOTE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_VOTE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_COMMIT'].fields_by_name['block_id']._loaded_options = None
  _globals['_COMMIT'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_COMMIT'].fields_by_name['signatures']._loaded_options = None
  _globals['_COMMIT'].fields_by_name['signatures']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITSIG'].fields_by_name['timestamp']._loaded_options = None
  _globals['_COMMITSIG'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDEDCOMMIT'].fields_by_name['block_id']._loaded_options = None
  _globals['_EXTENDEDCOMMIT'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_EXTENDEDCOMMIT'].fields_by_name['extended_signatures']._loaded_options = None
  _globals['_EXTENDEDCOMMIT'].fields_by_name['extended_signatures']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITSIG'].fields_by_name['timestamp']._loaded_options = None
  _globals['_EXTENDEDCOMMITSIG'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_PROPOSAL'].fields_by_name['block_id']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_PROPOSAL'].fields_by_name['timestamp']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_BLOCKMETA'].fields_by_name['block_id']._loaded_options = None
  _globals['_BLOCKMETA'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_BLOCKMETA'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCKMETA'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDMSGTYPE']._serialized_start=2816
  _globals['_SIGNEDMSGTYPE']._serialized_end=3031
  _globals['_PARTSETHEADER']._serialized_start=207
  _globals['_PARTSETHEADER']._serialized_end=251
  _globals['_PART']._serialized_start=253
  _globals['_PART']._serialized_end=337
  _globals['_BLOCKID']._serialized_start=339
  _globals['_BLOCKID']._serialized_end=427
  _globals['_HEADER']._serialized_start=430
  _globals['_HEADER']._serialized_end=867
  _globals['_DATA']._serialized_start=869
  _globals['_DATA']._serialized_end=888
  _globals['_VOTE']._serialized_start=891
  _globals['_VOTE']._serialized_end=1277
  _globals['_COMMIT']._serialized_start=1280
  _globals['_COMMIT']._serialized_end=1438
  _globals['_COMMITSIG']._serialized_start=1441
  _globals['_COMMITSIG']._serialized_end=1610
  _globals['_EXTENDEDCOMMIT']._serialized_start=1613
  _globals['_EXTENDEDCOMMIT']._serialized_end=1796
  _globals['_EXTENDEDCOMMITSIG']._serialized_start=1799
  _globals['_EXTENDEDCOMMITSIG']._serialized_end=2086
  _globals['_PROPOSAL']._serialized_start=2089
  _globals['_PROPOSAL']._serialized_end=2336
  _globals['_SIGNEDHEADER']._serialized_start=2338
  _globals['_SIGNEDHEADER']._serialized_end=2438
  _globals['_LIGHTBLOCK']._serialized_start=2440
  _globals['_LIGHTBLOCK']._serialized_end=2564
  _globals['_BLOCKMETA']._serialized_start=2567
  _globals['_BLOCKMETA']._serialized_end=2727
  _globals['_TXPROOF']._serialized_start=2729
  _globals['_TXPROOF']._serialized_end=2813
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cometbft.abci.v1beta1 import types_pb2 as _types_pb2
from cometbft.types.v1beta1 import types_pb2 as _types_pb2_1
from cometbft.types.v1beta2 import params_pb2 as _params_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MisbehaviorType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN: _ClassVar[MisbehaviorType]
    DUPLICATE_VOTE: _ClassVar[MisbehaviorType]
    LIGHT_CLIENT_ATTACK: _ClassVar[MisbehaviorType]
UNKNOWN: MisbehaviorType
DUPLICATE_VOTE: MisbehaviorType
LIGHT_CLIENT_ATTACK: MisbehaviorType

class Request(_message.Message):
    __slots__ = ("echo", "flush", "info", "init_chain", "query", "begin_block", "check_tx", "deliver_tx", "end_block", "commit", "list_snapshots", "offer_snapshot", "load_snapshot_chunk", "apply_snapshot_chunk", "prepare_proposal", "process_proposal")
    ECHO_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    PREPARE_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    PROCESS_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    echo: _types_pb2.RequestEcho
    flush: _types_pb2.RequestFlush
    info: RequestInfo
    init_chain: RequestInitChain
    query: _types_pb2.RequestQuery
    begin_block: RequestBeginBlock
    check_tx: _types_pb2.RequestCheckTx
    deliver_tx: _types_pb2.RequestDeliverTx
    end_block: _types_pb2.RequestEndBlock
    commit: _types_pb2.RequestCommit
    list_snapshots: _types_pb2.RequestListSnapshots
    offer_snapshot: _types_pb2.RequestOfferSnapshot
    load_snapshot_chunk: _types_pb2.RequestLoadSnapshotChunk
    apply_snapshot_chunk: _types_pb2.RequestApplySnapshotChunk
    prepare_proposal: RequestPrepareProposal
    process_proposal: RequestProcessProposal
    def __init__(self, echo: _Optional[_Union[_types_pb2.RequestEcho, _Mapping]] = ..., flush: _Optional[_Union[_types_pb2.RequestFlush, _Mapping]] = ..., info: _Optional[_Union[RequestInfo, _Mapping]] = ..., init_chain: _Optional[_Union[RequestInitChain, _Mapping]] = ..., query: _Optional[_Union[_types_pb2.RequestQuery, _Mapping]] = ..., begin_block: _Optional[_Union[RequestBeginBlock, _Mapping]] = ..., check_tx: _Optional[_Union[_types_pb2.RequestCheckTx, _Mapping]] = ..., deliver_tx: _Optional[_Union[_types_pb2.RequestDeliverTx, _Mapping]] = ..., end_block: _Optional[_Union[_types_pb2.RequestEndBlock, _Mapping]] = ..., commit: _Optional[_Union[_types_pb2.RequestCommit, _Mapping]] = ..., list_snapshots: _Optional[_Union[_types_pb2.RequestListSnapshots, _Mapping]] = ..., offer_snapshot: _Optional[_Union[_types_pb2.RequestOfferSnapshot, _Mapping]] = ..., load_snapshot_chunk: _Optional[_Union[_types_pb2.RequestLoadSnapshotChunk, _Mapping]] = ..., apply_snapshot_chunk: _Optional[_Union[_types_pb2.RequestApplySnapshotChunk, _Mapping]] = ..., prepare_proposal: _Optional[_Union[RequestPrepareProposal, _Mapping]] = ..., process_proposal: _Optional[_Union[RequestProcessProposal, _Mapping]] = ...) -> None: ...

class RequestInfo(_message.Message):
    __slots__ = ("version", "block_version", "p2p_version", "abci_version")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    BLOCK_VERSION_FIELD_NUMBER: _ClassVar[int]
    P2P_VERSION_FIELD_NUMBER: _ClassVar[int]
    ABCI_VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    block_version: int
    p2p_version: int
    abci_version: str
    def __init__(self, version: _Optional[str] = ..., block_version: _Optional[int] = ..., p2p_version: _Optional[int] = ..., abci_version: _Optional[str] = ...) -> None: ...

class RequestInitChain(_message.Message):
    __slots__ = ("time", "chain_id", "consensus_params", "validators", "app_state_bytes", "initial_height")
    TIME_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    APP_STATE_BYTES_FIELD_NUMBER: _ClassVar[int]
    INITIAL_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    time: _timestamp_pb2.Timestamp
    chain_id: str
    consensus_params: _params_pb2.ConsensusParams
    validators: _containers.RepeatedCompositeFieldContainer[_types_pb2.ValidatorUpdate]
    app_state_bytes: bytes
    initial_height: int
    def __init__(self, time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., chain_id: _Optional[str] = ..., consensus_params: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., validators: _Optional[_Iterable[_Union[_types_pb2.ValidatorUpdate, _Mapping]]] = ..., app_state_bytes: _Optional[bytes] = ..., initial_height: _Optional[int] = ...) -> None: ...

class RequestBeginBlock(_message.Message):
    __slots__ = ("hash", "header", "last_commit_info", "byzantine_validators")
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_INFO_FIELD_NUMBER: _ClassVar[int]
    BYZANTINE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    header: _types_pb2_1.Header
    last_commit_info: CommitInfo
    byzantine_validators: _containers.RepeatedCompositeFieldContainer[Misbehavior]
    def __init__(self, hash: _Optional[bytes] = ..., header: _Optional[_Union[_types_pb2_1.Header, _Mapping]] = ..., last_commit_info: _Optional[_Union[CommitInfo, _Mapping]] = ..., byzantine_validators: _Optional[_Iterable[_Union[Misbehavior, _Mapping]]] = ...) -> None: ...

class RequestPrepareProposal(_message.Message):
    __slots__ = ("max_tx_bytes", "txs", "local_last_commit", "misbehavior", "height", "time", "next_validators_hash", "proposer_address")
    MAX_TX_BYTES_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    MISBEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    max_tx_bytes: int
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    local_last_commit: ExtendedCommitInfo
    misbehavior: _containers.RepeatedCompositeFieldContainer[Misbehavior]
    height: int
    time: _timestamp_pb2.Timestamp
    next_validators_hash: bytes
    proposer_address: bytes
    def __init__(self, max_tx_bytes: _Optional[int] = ..., txs: _Optional[_Iterable[bytes]] = ..., local_last_commit: _Optional[_Union[ExtendedCommitInfo, _Mapping]] = ..., misbehavior: _Optional[_Iterable[_Union[Misbehavior, _Mapping]]] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., next_validators_hash: _Optional[bytes] = ..., proposer_address: _Optional[bytes] = ...) -> None: ...

class RequestProcessProposal(_message.Message):
    __slots__ = ("txs", "proposed_last_commit", "misbehavior", "hash", "height", "time", "next_validators_hash", "proposer_address")
    TXS_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    MISBEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    proposed_last_commit: CommitInfo
    misbehavior: _containers.RepeatedCompositeFieldContainer[Misbehavior]
    hash: bytes
    height: int
    time: _timestamp_pb2.Timestamp
    next_validators_hash: bytes
    proposer_address: bytes
    def __init__(self, txs: _Optional[_Iterable[bytes]] = ..., proposed_last_commit: _Optional[_Union[CommitInfo, _Mapping]] = ..., misbehavior: _Optional[_Iterable[_Union[Misbehavior, _Mapping]]] = ..., hash: _Optional[bytes] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., next_validators_hash: _Optional[bytes] = ..., proposer_address: _Optional[bytes] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ("exception", "echo", "flush", "info", "init_chain", "query", "begin_block", "check_tx", "deliver_tx", "end_block", "commit", "list_snapshots", "offer_snapshot", "load_snapshot_chunk", "apply_snapshot_chunk", "prepare_proposal", "process_proposal")
    EXCEPTION_FIELD_NUMBER: _ClassVar[int]
    ECHO_FIELD_NUMBER: _ClassVar[int]
    FLUSH_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    INIT_CHAIN_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    LIST_SNAPSHOTS_FIELD_NUMBER: _ClassVar[int]
    OFFER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: _ClassVar[int]
    PREPARE_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    PROCESS_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    exception: _types_pb2.ResponseException
    echo: _types_pb2.ResponseEcho
    flush: _types_pb2.ResponseFlush
    info: _types_pb2.ResponseInfo
    init_chain: ResponseInitChain
    query: _types_pb2.ResponseQuery
    begin_block: ResponseBeginBlock
    check_tx: ResponseCheckTx
    deliver_tx: ResponseDeliverTx
    end_block: ResponseEndBlock
    commit: _types_pb2.ResponseCommit
    list_snapshots: _types_pb2.ResponseListSnapshots
    offer_snapshot: _types_pb2.ResponseOfferSnapshot
    load_snapshot_chunk: _types_pb2.ResponseLoadSnapshotChunk
    apply_snapshot_chunk: _types_pb2.ResponseApplySnapshotChunk
    prepare_proposal: ResponsePrepareProposal
    process_proposal: ResponseProcessProposal
    def __init__(self, exception: _Optional[_Union[_types_pb2.ResponseException, _Mapping]] = ..., echo: _Optional[_Union[_types_pb2.ResponseEcho, _Mapping]] = ..., flush: _Optional[_Union[_types_pb2.ResponseFlush, _Mapping]] = ..., info: _Optional[_Union[_types_pb2.ResponseInfo, _Mapping]] = ..., init_chain: _Optional[_Union[ResponseInitChain, _Mapping]] = ..., query: _Optional[_Union[_types_pb2.ResponseQuery, _Mapping]] = ..., begin_block: _Optional[_Union[ResponseBeginBlock, _Mapping]] = ..., check_tx: _Optional[_Union[ResponseCheckTx, _Mapping]] = ..., deliver_tx: _Optional[_Union[ResponseDeliverTx, _Mapping]] = ..., end_block: _Optional[_Union[ResponseEndBlock, _Mapping]] = ..., commit: _Optional[_Union[_types_pb2.ResponseCommit, _Mapping]] = ..., list_snapshots: _Optional[_Union[_types_pb2.ResponseListSnapshots, _Mapping]] = ..., offer_snapshot: _Optional[_Union[_types_pb2.ResponseOfferSnapshot, _Mapping]] = ..., load_snapshot_chunk: _Optional[_Union[_types_pb2.ResponseLoadSnapshotChunk, _Mapping]] = ..., apply_snapshot_chunk: _Optional[_Union[_types_pb2.ResponseApplySnapshotChunk, _Mapping]] = ..., prepare_proposal: _Optional[_Union[ResponsePrepareProposal, _Mapping]] = ..., process_proposal: _Optional[_Union[ResponseProcessProposal, _Mapping]] = ...) -> None: ...

class ResponseInitChain(_message.Message):
    __slots__ = ("consensus_params", "validators", "app_hash")
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    consensus_params: _params_pb2.ConsensusParams
    validators: _containers.RepeatedCompositeFieldContainer[_types_pb2.ValidatorUpdate]
    app_hash: bytes
    def __init__(self, consensus_params: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., validators: _Optional[_Iterable[_Union[_types_pb2.ValidatorUpdate, _Mapping]]] = ..., app_hash: _Optional[bytes] = ...) -> None: ...

class ResponseBeginBlock(_message.Message):
    __slots__ = ("events",)
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[Event]
    def __init__(self, events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ...) -> None: ...

class ResponseCheckTx(_message.Message):
    __slots__ = ("code", "data", "log", "info", "gas_wanted", "gas_used", "events", "codespace", "sender", "priority", "mempool_error")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    MEMPOOL_ERROR_FIELD_NUMBER: _ClassVar[int]
    code: int
    data: bytes
    log: str
    info: str
    gas_wanted: int
    gas_used: int
    events: _containers.RepeatedCompositeFieldContainer[Event]
    codespace: str
    sender: str
    priority: int
    mempool_error: str
    def __init__(self, code: _Optional[int] = ..., data: _Optional[bytes] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., codespace: _Optional[str] = ..., sender: _Optional[str] = ..., priority: _Optional[int] = ..., mempool_error: _Optional[str] = ...) -> None: ...

class ResponseDeliverTx(_message.Message):
    __slots__ = ("code", "data", "log", "info", "gas_wanted", "gas_used", "events", "codespace")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    LOG_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    GAS_WANTED_FIELD_NUMBER: _ClassVar[int]
    GAS_USED_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CODESPACE_FIELD_NUMBER: _ClassVar[int]
    code: int
    data: bytes
    log: str
    info: str
    gas_wanted: int
    gas_used: int
    events: _containers.RepeatedCompositeFieldContainer[Event]
    codespace: str
    def __init__(self, code: _Optional[int] = ..., data: _Optional[bytes] = ..., log: _Optional[str] = ..., info: _Optional[str] = ..., gas_wanted: _Optional[int] = ..., gas_used: _Optional[int] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ..., codespace: _Optional[str] = ...) -> None: ...

class ResponseEndBlock(_message.Message):
    __slots__ = ("validator_updates", "consensus_param_updates", "events")
    VALIDATOR_UPDATES_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAM_UPDATES_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    validator_updates: _containers.RepeatedCompositeFieldContainer[_types_pb2.ValidatorUpdate]
    consensus_param_updates: _params_pb2.ConsensusParams
    events: _containers.RepeatedCompositeFieldContainer[Event]
    def __init__(self, validator_updates: _Optional[_Iterable[_Union[_types_pb2.ValidatorUpdate, _Mapping]]] = ..., consensus_param_updates: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ...) -> None: ...

class ResponsePrepareProposal(_message.Message):
    __slots__ = ("txs",)
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, txs: _Optional[_Iterable[bytes]] = ...) -> None: ...

class ResponseProcessProposal(_message.Message):
    __slots__ = ("status",)
    class ProposalStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[ResponseProcessProposal.ProposalStatus]
        ACCEPT: _ClassVar[ResponseProcessProposal.ProposalStatus]
        REJECT: _ClassVar[ResponseProcessProposal.ProposalStatus]
    UNKNOWN: ResponseProcessProposal.ProposalStatus
    ACCEPT: ResponseProcessProposal.ProposalStatus
    REJECT: ResponseProcessProposal.ProposalStatus
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: ResponseProcessProposal.ProposalStatus
    def __init__(self, status: _Optional[_Union[ResponseProcessProposal.ProposalStatus, str]] = ...) -> None: ...

class CommitInfo(_message.Message):
    __slots__ = ("round", "votes")
    ROUND_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    round: int
    votes: _containers.RepeatedCompositeFieldContainer[_types_pb2.VoteInfo]
    def __init__(self, round: _Optional[int] = ..., votes: _Optional[_Iterable[_Union[_types_pb2.VoteInfo, _Mapping]]] = ...) -> None: ...

class ExtendedCommitInfo(_message.Message):
    __slots__ = ("round", "votes")
    ROUND_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    round: int
    votes: _containers.RepeatedCompositeFieldContainer[ExtendedVoteInfo]
    def __init__(self, round: _Optional[int] = ..., votes: _Optional[_Iterable[_Union[ExtendedVoteInfo, _Mapping]]] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ("type", "attributes")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    type: str
    attributes: _containers.RepeatedCompositeFieldContainer[EventAttribute]
    def __init__(self, type: _Optional[str] = ..., attributes: _Optional[_Iterable[_Union[EventAttribute, _Mapping]]] = ...) -> None: ...

class EventAttribute(_message.Message):
    __slots__ = ("key", "value", "index")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    index: bool
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ..., index: bool = ...) -> None: ...

class ExtendedVoteInfo(_message.Message):
    __slots__ = ("validator", "signed_last_block", "vote_extension")
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    SIGNED_LAST_BLOCK_FIELD_NUMBER: _ClassVar[int]
    VOTE_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    validator: _types_pb2.Validator
    signed_last_block: bool
    vote_extension: bytes
    def __init__(self, validator: _Optional[_Union[_types_pb2.Validator, _Mapping]] = ..., signed_last_block: bool = ..., vote_extension: _Optional[bytes] = ...) -> None: ...

class Misbehavior(_message.Message):
    __slots__ = ("type", "validator", "height", "time", "total_voting_power")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    type: MisbehaviorType
    validator: _types_pb2.Validator
    height: int
    time: _timestamp_pb2.Timestamp
    total_voting_power: int
    def __init__(self, type: _Optional[_Union[MisbehaviorType, str]] = ..., validator: _Optional[_Union[_types_pb2.Validator, _Mapping]] = ..., height: _Optional[int] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., total_voting_power: _Optional[int] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.bank.v1beta1 import bank_pb2 as _bank_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSend(_message.Message):
    __slots__ = ("from_address", "to_address", "amount")
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    from_address: str
    to_address: str
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, from_address: _Optional[str] = ..., to_address: _Optional[str] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class MsgSendResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgMultiSend(_message.Message):
    __slots__ = ("inputs", "outputs")
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    inputs: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Input]
    outputs: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Output]
    def __init__(self, inputs: _Optional[_Iterable[_Union[_bank_pb2.Input, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[_bank_pb2.Output, _Mapping]]] = ...) -> None: ...

class MsgMultiSendResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/ganglion/stake_info.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/ganglion/stake_info.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!neurion/ganglion/stake_info.proto\x12\x10neurion.ganglion\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xa7\x01\n\tStakeInfo\x12;\n\x06\x61mount\x18\x01 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12\x18\n\x10last_update_time\x18\x02 \x01(\x04\x12\x43\n\x0eweighted_stake\x18\x03 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntB\x1aZ\x18neurion/x/ganglion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.ganglion.stake_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/ganglion/types'
  _globals['_STAKEINFO'].fields_by_name['amount']._loaded_options = None
  _globals['_STAKEINFO'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_STAKEINFO'].fields_by_name['weighted_stake']._loaded_options = None
  _globals['_STAKEINFO'].fields_by_name['weighted_stake']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_STAKEINFO']._serialized_start=105
  _globals['_STAKEINFO']._serialized_end=272
# @@protoc_insertion_point(module_scope)



class QueryError(RuntimeError):
    """Invalid Query Error."""


class NotFoundError(QueryError):
    """Not found Error."""


class QueryTimeoutError(QueryError):
    """Query timeout Error."""


class BroadcastError(RuntimeError):
    """Broadcast Error."""

    def __init__(self, tx_hash: str, message: str):
        """Init Broadcast error.

        :param tx_hash: transaction hash
        :param message: message
        """
        super().__init__(message)
        self.tx_hash = tx_hash


class OutOfGasError(BroadcastError):
    """Insufficient Fess Error."""

    def __init__(self, tx_hash: str, gas_wanted: int, gas_used: int):
        """Initialize.

        :param tx_hash: transaction hash
        :param gas_wanted: gas required to complete the transaction
        :param gas_used: gas used
        """
        self.gas_wanted = gas_wanted
        self.gas_used = gas_used
        super().__init__(
            tx_hash, f"Out of Gas (wanted: {self.gas_wanted}, used: {self.gas_used})"
        )


class InsufficientFeesError(BroadcastError):
    """Insufficient Fess Error."""

    def __init__(self, tx_hash: str, minimum_required_fee: str):
        """Initialize.

        :param tx_hash: transaction hash
        :param minimum_required_fee: Minimum required fee
        """
        self.minimum_required_fee = minimum_required_fee
        super().__init__(
            tx_hash,
            f"Insufficient Fees (minimum required: {self.minimum_required_fee})",
        )



from neurionpy.crypto.address import Address
from neurionpy.protos.cosmos.bank.v1beta1.tx_pb2 import MsgSend
from neurionpy.protos.cosmos.base.v1beta1.coin_pb2 import Coin


def create_bank_send_msg(
    from_address: Address, to_address: Address, amount: int, denom: str
) -> MsgSend:
    """Create bank send message.

    :param from_address: from address
    :param to_address: to address
    :param amount: amount
    :param denom: denom
    :return: bank send message
    """
    msg = MsgSend(
        from_address=str(from_address),
        to_address=str(to_address),
        amount=[Coin(amount=str(amount), denom=denom)],
    )

    return msg



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/params/v1beta1/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/params/v1beta1/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/params/v1beta1/params.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\"\x82\x01\n\x17ParameterChangeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x39\n\x07\x63hanges\x18\x03 \x03(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\x04\xc8\xde\x1f\x00:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"A\n\x0bParamChange\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t:\x04\x98\xa0\x1f\x00\x42:Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.v1beta1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\250\342\036\001'
  _globals['_PARAMETERCHANGEPROPOSAL'].fields_by_name['changes']._loaded_options = None
  _globals['_PARAMETERCHANGEPROPOSAL'].fields_by_name['changes']._serialized_options = b'\310\336\037\000'
  _globals['_PARAMETERCHANGEPROPOSAL']._loaded_options = None
  _globals['_PARAMETERCHANGEPROPOSAL']._serialized_options = b'\210\240\037\000\230\240\037\000'
  _globals['_PARAMCHANGE']._loaded_options = None
  _globals['_PARAMCHANGE']._serialized_options = b'\230\240\037\000'
  _globals['_PARAMETERCHANGEPROPOSAL']._serialized_start=84
  _globals['_PARAMETERCHANGEPROPOSAL']._serialized_end=214
  _globals['_PARAMCHANGE']._serialized_start=216
  _globals['_PARAMCHANGE']._serialized_end=281
# @@protoc_insertion_point(module_scope)



from typing import Optional

from neurionpy.protos.neurion.ganglion.tx_pb2 import (
    MsgUpdateParams,
    MsgUpdateParamsResponse,
    MsgRegisterIon,
    MsgRegisterIonResponse,
    MsgReportUnavailableIon,
    MsgReportUnavailableIonResponse,
    MsgUnreportUnavailableIon,
    MsgUnreportUnavailableIonResponse,
    MsgAddValidator,
    MsgAddValidatorResponse,
    MsgRemoveValidator,
    MsgRemoveValidatorResponse,
    MsgValidateAvailability,
    MsgValidateAvailabilityResponse,
    MsgRegisterPathway,
    MsgRegisterPathwayResponse,
    MsgStakePathway,
    MsgStakePathwayResponse,
    MsgRefundPathwayStake,
    MsgRefundPathwayStakeResponse,
    MsgInitUnstakePathway,
    MsgInitUnstakePathwayResponse,
    MsgClaimProtocolFee,
    MsgClaimProtocolFeeResponse,
    MsgSettlePathwayStake,
    MsgSettlePathwayStakeResponse,
    MsgStakeToGanglion,
    MsgStakeToGanglionResponse,
    MsgClaimReward,
    MsgClaimRewardResponse,
    MsgUnstakeFromGanglion,
    MsgUnstakeFromGanglionResponse,
    MsgUpdatePathway,
    MsgUpdatePathwayResponse, MsgRemoveIon, MsgRemovePathway,
)
from neurionpy.ganglion.interface import GanglionMessage
from neurionpy.synapse.tx import Transaction
from neurionpy.synapse.tx_helpers import SubmittedTx
from neurionpy.synapse.utils import NeurionUtils
from neurionpy.synapse.wallet import Wallet


class GanglionMsgClient(GanglionMessage):
    def __init__(self, utils: NeurionUtils, wallet: Optional[Wallet]) -> None:
        """
        Initialize the Ganglion message client.

        :param utils: NeurionUtils instance for transaction preparation and broadcasting.
        :param wallet: Wallet instance for signing transactions.
        """
        if wallet is None:
            raise ValueError("A wallet must be provided to initialize GanglionMsgClient.")
        self.utils = utils
        self.wallet = wallet

    def _set_creator(self, message):
        """
        If the message has a 'creator' field and it is not set, assign the wallet address.
        """
        if hasattr(message, "creator") and not message.creator:
            message.creator = str(self.wallet.address())

    def UpdateParams(
        self,
        message: MsgUpdateParams,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Update module parameters.
        Note: This message uses an 'authority' field, so no creator defaulting.
        """
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RegisterIon(
        self,
        message: MsgRegisterIon,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Register an Ion."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RemoveIon(
        self,
        message: MsgRemoveIon,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Update an existing pathway."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ReportUnavailableIon(
        self,
        message: MsgReportUnavailableIon,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Report an unavailable Ion."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def UnreportUnavailableIon(
        self,
        message: MsgUnreportUnavailableIon,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Unreport an unavailable Ion."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def AddValidator(
        self,
        message: MsgAddValidator,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Add a validator."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RemoveValidator(
        self,
        message: MsgRemoveValidator,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Remove a validator."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ValidateAvailability(
        self,
        message: MsgValidateAvailability,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Validate the availability of an Ion."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RegisterPathway(
        self,
        message: MsgRegisterPathway,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Register a pathway."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def StakePathway(
        self,
        message: MsgStakePathway,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Stake tokens to a pathway."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RefundPathwayStake(
        self,
        message: MsgRefundPathwayStake,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Refund pathway stake."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def InitUnstakePathway(
        self,
        message: MsgInitUnstakePathway,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Initiate unstaking for a pathway."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ClaimProtocolFee(
        self,
        message: MsgClaimProtocolFee,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Claim the protocol fee."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def SettlePathwayStake(
        self,
        message: MsgSettlePathwayStake,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Settle a pathway stake."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def StakeToGanglion(
        self,
        message: MsgStakeToGanglion,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Stake tokens to Ganglion."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def ClaimReward(
        self,
        message: MsgClaimReward,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Claim reward."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def UnstakeFromGanglion(
        self,
        message: MsgUnstakeFromGanglion,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Unstake tokens from Ganglion."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def UpdatePathway(
        self,
        message: MsgUpdatePathway,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Update an existing pathway."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )

    def RemovePathway(
        self,
        message: MsgRemovePathway,
        memo: Optional[str] = None,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Update an existing pathway."""
        self._set_creator(message)
        tx = Transaction()
        tx.add_message(message)
        return self.utils.prepare_and_broadcast_basic_transaction(
            tx, self.wallet, gas_limit=gas_limit, memo=memo
        )